# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/common/v1/common_v1.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/common/v1/common_v1.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dnds/common/v1/common_v1.proto\x12\rnds.common.v1\"\x7f\n\x0eRequestContext\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestId\x12\'\n\x0fidempotency_key\x18\x02 \x01(\tR\x0eidempotencyKey\x12%\n\x0e\x63orrelation_id\x18\x03 \x01(\x0cR\rcorrelationId\"\xc1\x02\n\x0b\x45rrorStatus\x12\x12\n\x04\x63ode\x18\x01 \x01(\tR\x04\x63ode\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12\x38\n\x08\x63\x61tegory\x18\x03 \x01(\x0e\x32\x1c.nds.common.v1.ErrorCategoryR\x08\x63\x61tegory\x12\x41\n\x07\x64\x65tails\x18\x04 \x03(\x0b\x32\'.nds.common.v1.ErrorStatus.DetailsEntryR\x07\x64\x65tails\x12\x33\n\x13retry_after_seconds\x18\x05 \x01(\x05H\x00R\x11retryAfterSeconds\x88\x01\x01\x1a:\n\x0c\x44\x65tailsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x16\n\x14_retry_after_seconds*\xbe\x01\n\rErrorCategory\x12\x1e\n\x1a\x45RROR_CATEGORY_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x45RROR_CATEGORY_RETRYABLE\x10\x01\x12\x1b\n\x17\x45RROR_CATEGORY_CONFLICT\x10\x02\x12\x19\n\x15\x45RROR_CATEGORY_POLICY\x10\x03\x12\x1d\n\x19\x45RROR_CATEGORY_VALIDATION\x10\x04\x12\x18\n\x14\x45RROR_CATEGORY_FATAL\x10\x05\x42\xd7\x01\n8noie.linmimeng.noiedigitalsystem.api.proto.nds.common.v1B\rCommonV1ProtoP\x01Z6github.com/misty4119/nds-api/Go/nds/common/v1;commonv1\xa2\x02\x03NCX\xaa\x02\rNds.Common.V1\xca\x02\rNds\\Common\\V1\xe2\x02\x19Nds\\Common\\V1\\GPBMetadata\xea\x02\x0fNds::Common::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.common.v1.common_v1_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n8noie.linmimeng.noiedigitalsystem.api.proto.nds.common.v1B\rCommonV1ProtoP\001Z6github.com/misty4119/nds-api/Go/nds/common/v1;commonv1\242\002\003NCX\252\002\rNds.Common.V1\312\002\rNds\\Common\\V1\342\002\031Nds\\Common\\V1\\GPBMetadata\352\002\017Nds::Common::V1'
  _globals['_ERRORSTATUS_DETAILSENTRY']._loaded_options = None
  _globals['_ERRORSTATUS_DETAILSENTRY']._serialized_options = b'8\001'
  _globals['_ERRORCATEGORY']._serialized_start=502
  _globals['_ERRORCATEGORY']._serialized_end=692
  _globals['_REQUESTCONTEXT']._serialized_start=48
  _globals['_REQUESTCONTEXT']._serialized_end=175
  _globals['_ERRORSTATUS']._serialized_start=178
  _globals['_ERRORSTATUS']._serialized_end=499
  _globals['_ERRORSTATUS_DETAILSENTRY']._serialized_start=417
  _globals['_ERRORSTATUS_DETAILSENTRY']._serialized_end=475
# @@protoc_insertion_point(module_scope)
