# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/sync/v1/sync.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/sync/v1/sync.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nds.common.v1 import common_v1_pb2 as nds_dot_common_dot_v1_dot_common__v1__pb2
from nds.event.v1 import event_v1_pb2 as nds_dot_event_dot_v1_dot_event__v1__pb2
from nds.identity.v1 import identity_v1_pb2 as nds_dot_identity_dot_v1_dot_identity__v1__pb2
from nds.ledger.v1 import ledger_pb2 as nds_dot_ledger_dot_v1_dot_ledger__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16nds/sync/v1/sync.proto\x12\x0bnds.sync.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dnds/common/v1/common_v1.proto\x1a\x1bnds/event/v1/event_v1.proto\x1a!nds/identity/v1/identity_v1.proto\x1a\x1ands/ledger/v1/ledger.proto\"#\n\x0bResumeToken\x12\x14\n\x05value\x18\x01 \x01(\x0cR\x05value\"\xa9\x03\n\x16SubscribeEventsRequest\x12\x35\n\x06resume\x18\x01 \x01(\x0b\x32\x18.nds.sync.v1.ResumeTokenH\x00R\x06resume\x88\x01\x01\x12\x35\n\x05since\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\x05since\x88\x01\x01\x12-\n\x05types\x18\x03 \x03(\x0e\x32\x17.nds.event.v1.EventTypeR\x05types\x12\x35\n\x05owner\x18\x04 \x01(\x0b\x32\x1a.nds.identity.v1.PersonaIdH\x02R\x05owner\x88\x01\x01\x12\x31\n\x15max_events_per_second\x18\n \x01(\x05R\x12maxEventsPerSecond\x12\'\n\rmax_in_flight\x18\x0b \x01(\x05H\x03R\x0bmaxInFlight\x88\x01\x01\x12 \n\tpage_size\x18\x0c \x01(\x05H\x04R\x08pageSize\x88\x01\x01\x42\t\n\x07_resumeB\x08\n\x06_sinceB\x08\n\x06_ownerB\x10\n\x0e_max_in_flightB\x0c\n\n_page_size\"\xd0\x02\n\x17SubscribeEventsResponse\x12\x35\n\x06resume\x18\x01 \x01(\x0b\x32\x18.nds.sync.v1.ResumeTokenH\x01R\x06resume\x88\x01\x01\x12:\n\x08ordering\x18\x02 \x01(\x0e\x32\x19.nds.sync.v1.OrderingModeH\x02R\x08ordering\x88\x01\x01\x12\x33\n\x05\x65vent\x18\n \x01(\x0b\x32\x1b.nds.event.v1.EventEnvelopeH\x00R\x05\x65vent\x12\x36\n\theartbeat\x18\x0b \x01(\x0b\x32\x16.nds.sync.v1.HeartbeatH\x00R\theartbeat\x12\x32\n\x05\x65rror\x18\x0c \x01(\x0b\x32\x1a.nds.common.v1.ErrorStatusH\x00R\x05\x65rrorB\t\n\x07messageB\t\n\x07_resumeB\x0b\n\t_ordering\"C\n\tHeartbeat\x12/\n\x02\x61t\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x02\x61t\x88\x01\x01\x42\x05\n\x03_at\"\xf4\x01\n\x13WatchBalanceRequest\x12+\n\x03key\x18\x01 \x01(\x0b\x32\x19.nds.ledger.v1.BalanceKeyR\x03key\x12\x35\n\x06resume\x18\x02 \x01(\x0b\x32\x18.nds.sync.v1.ResumeTokenH\x00R\x06resume\x88\x01\x01\x12\x33\n\x16max_updates_per_second\x18\n \x01(\x05R\x13maxUpdatesPerSecond\x12\'\n\rmax_in_flight\x18\x0b \x01(\x05H\x01R\x0bmaxInFlight\x88\x01\x01\x42\t\n\x07_resumeB\x10\n\x0e_max_in_flight\"q\n\x0f\x42\x61lanceSnapshot\x12\x30\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32\x16.nds.ledger.v1.BalanceR\x07\x62\x61lance\x12,\n\x06\x63ursor\x18\x02 \x01(\x0b\x32\x14.nds.event.v1.CursorR\x06\x63ursor\"\x94\x02\n\x0c\x42\x61lanceDelta\x12+\n\x03key\x18\x01 \x01(\x0b\x32\x19.nds.ledger.v1.BalanceKeyR\x03key\x12*\n\x05\x64\x65lta\x18\x02 \x01(\x0b\x32\x14.nds.ledger.v1.MoneyR\x05\x64\x65lta\x12\x1f\n\x0bnew_version\x18\x03 \x01(\x04R\nnewVersion\x12,\n\x06\x63ursor\x18\x04 \x01(\x0b\x32\x14.nds.event.v1.CursorR\x06\x63ursor\x12\x1e\n\x0bproof_tx_id\x18\x05 \x01(\x0cR\tproofTxId\x12)\n\x0eproof_event_id\x18\x06 \x01(\x0cH\x00R\x0cproofEventId\x88\x01\x01\x42\x11\n\x0f_proof_event_id\"\x87\x03\n\x14WatchBalanceResponse\x12\x35\n\x06resume\x18\x01 \x01(\x0b\x32\x18.nds.sync.v1.ResumeTokenH\x01R\x06resume\x88\x01\x01\x12:\n\x08ordering\x18\x02 \x01(\x0e\x32\x19.nds.sync.v1.OrderingModeH\x02R\x08ordering\x88\x01\x01\x12:\n\x08snapshot\x18\n \x01(\x0b\x32\x1c.nds.sync.v1.BalanceSnapshotH\x00R\x08snapshot\x12\x31\n\x05\x64\x65lta\x18\x0b \x01(\x0b\x32\x19.nds.sync.v1.BalanceDeltaH\x00R\x05\x64\x65lta\x12\x32\n\x05\x65rror\x18\x0c \x01(\x0b\x32\x1a.nds.common.v1.ErrorStatusH\x00R\x05\x65rror\x12\x36\n\theartbeat\x18\r \x01(\x0b\x32\x16.nds.sync.v1.HeartbeatH\x00R\theartbeatB\t\n\x07messageB\t\n\x07_resumeB\x0b\n\t_ordering*e\n\x0cOrderingMode\x12\x1d\n\x19ORDERING_MODE_UNSPECIFIED\x10\x00\x12\x17\n\x13ORDERING_MODE_TOTAL\x10\x01\x12\x1d\n\x19ORDERING_MODE_PARTITIONED\x10\x02\x42\xc5\x01\n6noie.linmimeng.noiedigitalsystem.api.proto.nds.sync.v1B\tSyncProtoP\x01Z2github.com/misty4119/nds-api/Go/nds/sync/v1;syncv1\xa2\x02\x03NSX\xaa\x02\x0bNds.Sync.V1\xca\x02\x0bNds\\Sync\\V1\xe2\x02\x17Nds\\Sync\\V1\\GPBMetadata\xea\x02\rNds::Sync::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.sync.v1.sync_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n6noie.linmimeng.noiedigitalsystem.api.proto.nds.sync.v1B\tSyncProtoP\001Z2github.com/misty4119/nds-api/Go/nds/sync/v1;syncv1\242\002\003NSX\252\002\013Nds.Sync.V1\312\002\013Nds\\Sync\\V1\342\002\027Nds\\Sync\\V1\\GPBMetadata\352\002\rNds::Sync::V1'
  _globals['_ORDERINGMODE']._serialized_start=2103
  _globals['_ORDERINGMODE']._serialized_end=2204
  _globals['_RESUMETOKEN']._serialized_start=195
  _globals['_RESUMETOKEN']._serialized_end=230
  _globals['_SUBSCRIBEEVENTSREQUEST']._serialized_start=233
  _globals['_SUBSCRIBEEVENTSREQUEST']._serialized_end=658
  _globals['_SUBSCRIBEEVENTSRESPONSE']._serialized_start=661
  _globals['_SUBSCRIBEEVENTSRESPONSE']._serialized_end=997
  _globals['_HEARTBEAT']._serialized_start=999
  _globals['_HEARTBEAT']._serialized_end=1066
  _globals['_WATCHBALANCEREQUEST']._serialized_start=1069
  _globals['_WATCHBALANCEREQUEST']._serialized_end=1313
  _globals['_BALANCESNAPSHOT']._serialized_start=1315
  _globals['_BALANCESNAPSHOT']._serialized_end=1428
  _globals['_BALANCEDELTA']._serialized_start=1431
  _globals['_BALANCEDELTA']._serialized_end=1707
  _globals['_WATCHBALANCERESPONSE']._serialized_start=1710
  _globals['_WATCHBALANCERESPONSE']._serialized_end=2101
# @@protoc_insertion_point(module_scope)
