# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/asset/asset.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/asset/asset.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nds.common import common_pb2 as nds_dot_common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15nds/asset/asset.proto\x12\tnds.asset\x1a\x17nds/common/common.proto\"J\n\x07\x41ssetId\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12+\n\x05scope\x18\x02 \x01(\x0e\x32\x15.nds.asset.AssetScopeR\x05scope\"\x99\x03\n\x08NdsAsset\x12-\n\x08\x61sset_id\x18\x01 \x01(\x0b\x32\x12.nds.asset.AssetIdR\x07\x61ssetId\x12\x31\n\x04tags\x18\x02 \x03(\x0b\x32\x1d.nds.asset.NdsAsset.TagsEntryR\x04tags\x12=\n\x08metadata\x18\x03 \x03(\x0b\x32!.nds.asset.NdsAsset.MetadataEntryR\x08metadata\x12.\n\x05limit\x18\x04 \x01(\x0b\x32\x13.nds.common.DecimalH\x00R\x05limit\x88\x01\x01\x12\x1d\n\ncreated_at\x18\x05 \x01(\x03R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x06 \x01(\x03R\tupdatedAt\x1a\x37\n\tTagsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x08\n\x06_limit*q\n\nAssetScope\x12\x1b\n\x17\x41SSET_SCOPE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x41SSET_SCOPE_PLAYER\x10\x01\x12\x16\n\x12\x41SSET_SCOPE_SERVER\x10\x02\x12\x16\n\x12\x41SSET_SCOPE_GLOBAL\x10\x03\x42\xb2\x01\n4noie.linmimeng.noiedigitalsystem.api.proto.nds.assetB\nAssetProtoP\x01Z)github.com/misty4119/nds-api/Go/nds/asset\xa2\x02\x03NAX\xaa\x02\tNds.Asset\xca\x02\tNds\\Asset\xe2\x02\x15Nds\\Asset\\GPBMetadata\xea\x02\nNds::Assetb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.asset.asset_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n4noie.linmimeng.noiedigitalsystem.api.proto.nds.assetB\nAssetProtoP\001Z)github.com/misty4119/nds-api/Go/nds/asset\242\002\003NAX\252\002\tNds.Asset\312\002\tNds\\Asset\342\002\025Nds\\Asset\\GPBMetadata\352\002\nNds::Asset'
  _globals['_NDSASSET_TAGSENTRY']._loaded_options = None
  _globals['_NDSASSET_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_NDSASSET_METADATAENTRY']._loaded_options = None
  _globals['_NDSASSET_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_ASSETSCOPE']._serialized_start=549
  _globals['_ASSETSCOPE']._serialized_end=662
  _globals['_ASSETID']._serialized_start=61
  _globals['_ASSETID']._serialized_end=135
  _globals['_NDSASSET']._serialized_start=138
  _globals['_NDSASSET']._serialized_end=547
  _globals['_NDSASSET_TAGSENTRY']._serialized_start=421
  _globals['_NDSASSET_TAGSENTRY']._serialized_end=476
  _globals['_NDSASSET_METADATAENTRY']._serialized_start=478
  _globals['_NDSASSET_METADATAENTRY']._serialized_end=537
# @@protoc_insertion_point(module_scope)
