# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/ledger/v1/ledger.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/ledger/v1/ledger.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from nds.common.v1 import common_v1_pb2 as nds_dot_common_dot_v1_dot_common__v1__pb2
from nds.event.v1 import event_v1_pb2 as nds_dot_event_dot_v1_dot_event__v1__pb2
from nds.identity.v1 import identity_v1_pb2 as nds_dot_identity_dot_v1_dot_identity__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ands/ledger/v1/ledger.proto\x12\rnds.ledger.v1\x1a\x19google/protobuf/any.proto\x1a\x1dnds/common/v1/common_v1.proto\x1a\x1bnds/event/v1/event_v1.proto\x1a!nds/identity/v1/identity_v1.proto\"X\n\x05Money\x12#\n\rcurrency_code\x18\x01 \x01(\tR\x0c\x63urrencyCode\x12\x14\n\x05units\x18\x02 \x01(\x03R\x05units\x12\x14\n\x05nanos\x18\x03 \x01(\x05R\x05nanos\"c\n\nBalanceKey\x12\x30\n\x05owner\x18\x01 \x01(\x0b\x32\x1a.nds.identity.v1.PersonaIdR\x05owner\x12#\n\rcurrency_code\x18\x02 \x01(\tR\x0c\x63urrencyCode\"~\n\x07\x42\x61lance\x12+\n\x03key\x18\x01 \x01(\x0b\x32\x19.nds.ledger.v1.BalanceKeyR\x03key\x12,\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x14.nds.ledger.v1.MoneyR\x06\x61mount\x12\x18\n\x07version\x18\x03 \x01(\x04R\x07version\"\xc3\x04\n\x18\x43reateTransactionRequest\x12\x30\n\x05\x61\x63tor\x18\x01 \x01(\x0b\x32\x1a.nds.identity.v1.PersonaIdR\x05\x61\x63tor\x12\x37\n\x06source\x18\x02 \x01(\x0b\x32\x1a.nds.identity.v1.PersonaIdH\x00R\x06source\x88\x01\x01\x12\x37\n\x06target\x18\x03 \x01(\x0b\x32\x1a.nds.identity.v1.PersonaIdH\x01R\x06target\x88\x01\x01\x12,\n\x06\x61mount\x18\x04 \x01(\x0b\x32\x14.nds.ledger.v1.MoneyR\x06\x61mount\x12/\n\x03\x63tx\x18\n \x01(\x0b\x32\x1d.nds.common.v1.RequestContextR\x03\x63tx\x12;\n\x17\x65xpected_source_version\x18\x0b \x01(\x04H\x02R\x15\x65xpectedSourceVersion\x88\x01\x01\x12;\n\x17\x65xpected_target_version\x18\x0c \x01(\x04H\x03R\x15\x65xpectedTargetVersion\x88\x01\x01\x12\x1b\n\x06reason\x18\x14 \x01(\tH\x04R\x06reason\x88\x01\x01\x12\x34\n\nextensions\x18\x1e \x03(\x0b\x32\x14.google.protobuf.AnyR\nextensionsB\t\n\x07_sourceB\t\n\x07_targetB\x1a\n\x18_expected_source_versionB\x1a\n\x18_expected_target_versionB\t\n\x07_reason\"\xc2\x01\n\x19\x43reateTransactionResponse\x12\x18\n\x05tx_id\x18\x01 \x01(\x0cH\x00R\x04txId\x88\x01\x01\x12\x36\n\x05\x65vent\x18\x02 \x01(\x0b\x32\x1b.nds.event.v1.EventEnvelopeH\x01R\x05\x65vent\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x1a.nds.common.v1.ErrorStatusH\x02R\x05\x65rror\x88\x01\x01\x42\x08\n\x06_tx_idB\x08\n\x06_eventB\x08\n\x06_errorB\xd5\x01\n8noie.linmimeng.noiedigitalsystem.api.proto.nds.ledger.v1B\x0bLedgerProtoP\x01Z6github.com/misty4119/nds-api/Go/nds/ledger/v1;ledgerv1\xa2\x02\x03NLX\xaa\x02\rNds.Ledger.V1\xca\x02\rNds\\Ledger\\V1\xe2\x02\x19Nds\\Ledger\\V1\\GPBMetadata\xea\x02\x0fNds::Ledger::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.ledger.v1.ledger_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n8noie.linmimeng.noiedigitalsystem.api.proto.nds.ledger.v1B\013LedgerProtoP\001Z6github.com/misty4119/nds-api/Go/nds/ledger/v1;ledgerv1\242\002\003NLX\252\002\rNds.Ledger.V1\312\002\rNds\\Ledger\\V1\342\002\031Nds\\Ledger\\V1\\GPBMetadata\352\002\017Nds::Ledger::V1'
  _globals['_MONEY']._serialized_start=167
  _globals['_MONEY']._serialized_end=255
  _globals['_BALANCEKEY']._serialized_start=257
  _globals['_BALANCEKEY']._serialized_end=356
  _globals['_BALANCE']._serialized_start=358
  _globals['_BALANCE']._serialized_end=484
  _globals['_CREATETRANSACTIONREQUEST']._serialized_start=487
  _globals['_CREATETRANSACTIONREQUEST']._serialized_end=1066
  _globals['_CREATETRANSACTIONRESPONSE']._serialized_start=1069
  _globals['_CREATETRANSACTIONRESPONSE']._serialized_end=1263
# @@protoc_insertion_point(module_scope)
