# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/query/query.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/query/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nds.common import common_pb2 as nds_dot_common_dot_common__pb2
from nds.identity import identity_pb2 as nds_dot_identity_dot_identity__pb2
from nds.asset import asset_pb2 as nds_dot_asset_dot_asset__pb2
from nds.event import event_pb2 as nds_dot_event_dot_event__pb2
from nds.context import context_pb2 as nds_dot_context_dot_context__pb2
from nds.projection import projection_pb2 as nds_dot_projection_dot_projection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15nds/query/query.proto\x12\tnds.query\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17nds/common/common.proto\x1a\x1bnds/identity/identity.proto\x1a\x15nds/asset/asset.proto\x1a\x15nds/event/event.proto\x1a\x19nds/context/context.proto\x1a\x1fnds/projection/projection.proto\"\xcc\x01\n\x13QueryBalanceRequest\x12(\n\x05\x61sset\x18\x01 \x01(\x0b\x32\x12.nds.asset.AssetIdR\x05\x61sset\x12:\n\x08identity\x18\x02 \x01(\x0b\x32\x19.nds.identity.NdsIdentityH\x00R\x08identity\x88\x01\x01\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32\x17.nds.context.NdsContextH\x01R\x07\x63ontext\x88\x01\x01\x42\x0b\n\t_identityB\n\n\x08_context\"\x85\x01\n\x14QueryBalanceResponse\x12-\n\x06result\x18\x01 \x01(\x0b\x32\x15.nds.common.NdsResultR\x06result\x12\x32\n\x07\x62\x61lance\x18\x02 \x01(\x0b\x32\x13.nds.common.DecimalH\x00R\x07\x62\x61lance\x88\x01\x01\x42\n\n\x08_balance\"\xa1\x03\n\x13QueryHistoryRequest\x12-\n\x05\x61sset\x18\x01 \x01(\x0b\x32\x12.nds.asset.AssetIdH\x00R\x05\x61sset\x88\x01\x01\x12:\n\x08identity\x18\x02 \x01(\x0b\x32\x19.nds.identity.NdsIdentityH\x01R\x08identity\x88\x01\x01\x12>\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x02R\tstartTime\x88\x01\x01\x12:\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x03R\x07\x65ndTime\x88\x01\x01\x12\x14\n\x05limit\x18\x05 \x01(\x05R\x05limit\x12\x16\n\x06offset\x18\x06 \x01(\x05R\x06offset\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32\x17.nds.context.NdsContextH\x04R\x07\x63ontext\x88\x01\x01\x42\x08\n\x06_assetB\x0b\n\t_identityB\r\n\x0b_start_timeB\x0b\n\t_end_timeB\n\n\x08_context\"\x93\x01\n\x14QueryHistoryResponse\x12-\n\x06result\x18\x01 \x01(\x0b\x32\x15.nds.common.NdsResultR\x06result\x12+\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x13.nds.event.NdsEventR\x06\x65vents\x12\x1f\n\x0btotal_count\x18\x03 \x01(\x03R\ntotalCount\"\x9f\x01\n\x16QueryProjectionRequest\x12\x41\n\rprojection_id\x18\x01 \x01(\x0b\x32\x1c.nds.projection.ProjectionIdR\x0cprojectionId\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32\x17.nds.context.NdsContextH\x00R\x07\x63ontext\x88\x01\x01\x42\n\n\x08_context\"\x9b\x01\n\x17QueryProjectionResponse\x12-\n\x06result\x18\x01 \x01(\x0b\x32\x15.nds.common.NdsResultR\x06result\x12\x42\n\nprojection\x18\x02 \x01(\x0b\x32\x1d.nds.projection.NdsProjectionH\x00R\nprojection\x88\x01\x01\x42\r\n\x0b_projection\"\xd3\x01\n\rReplayRequest\x12\x41\n\rprojection_id\x18\x01 \x01(\x0b\x32\x1c.nds.projection.ProjectionIdR\x0cprojectionId\x12;\n\x0btarget_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ntargetTime\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32\x17.nds.context.NdsContextH\x00R\x07\x63ontext\x88\x01\x01\x42\n\n\x08_context\"\x92\x01\n\x0eReplayResponse\x12-\n\x06result\x18\x01 \x01(\x0b\x32\x15.nds.common.NdsResultR\x06result\x12\x42\n\nprojection\x18\x02 \x01(\x0b\x32\x1d.nds.projection.NdsProjectionH\x00R\nprojection\x88\x01\x01\x42\r\n\x0b_projection\"\xba\x01\n\x19RegisterProjectionRequest\x12\x41\n\rprojection_id\x18\x01 \x01(\x0b\x32\x1c.nds.projection.ProjectionIdR\x0cprojectionId\x12\x16\n\x06\x63onfig\x18\x02 \x01(\tR\x06\x63onfig\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32\x17.nds.context.NdsContextH\x00R\x07\x63ontext\x88\x01\x01\x42\n\n\x08_context\"K\n\x1aRegisterProjectionResponse\x12-\n\x06result\x18\x01 \x01(\x0b\x32\x15.nds.common.NdsResultR\x06result\"\xa4\x01\n\x1bUnregisterProjectionRequest\x12\x41\n\rprojection_id\x18\x01 \x01(\x0b\x32\x1c.nds.projection.ProjectionIdR\x0cprojectionId\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32\x17.nds.context.NdsContextH\x00R\x07\x63ontext\x88\x01\x01\x42\n\n\x08_context\"M\n\x1cUnregisterProjectionResponse\x12-\n\x06result\x18\x01 \x01(\x0b\x32\x15.nds.common.NdsResultR\x06result2\x98\x04\n\x0fNdsQueryService\x12O\n\x0cQueryBalance\x12\x1e.nds.query.QueryBalanceRequest\x1a\x1f.nds.query.QueryBalanceResponse\x12O\n\x0cQueryHistory\x12\x1e.nds.query.QueryHistoryRequest\x1a\x1f.nds.query.QueryHistoryResponse\x12X\n\x0fQueryProjection\x12!.nds.query.QueryProjectionRequest\x1a\".nds.query.QueryProjectionResponse\x12=\n\x06Replay\x12\x18.nds.query.ReplayRequest\x1a\x19.nds.query.ReplayResponse\x12\x61\n\x12RegisterProjection\x12$.nds.query.RegisterProjectionRequest\x1a%.nds.query.RegisterProjectionResponse\x12g\n\x14UnregisterProjection\x12&.nds.query.UnregisterProjectionRequest\x1a\'.nds.query.UnregisterProjectionResponseB\xb2\x01\n4noie.linmimeng.noiedigitalsystem.api.proto.nds.queryB\nQueryProtoP\x01Z)github.com/misty4119/nds-api/Go/nds/query\xa2\x02\x03NQX\xaa\x02\tNds.Query\xca\x02\tNds\\Query\xe2\x02\x15Nds\\Query\\GPBMetadata\xea\x02\nNds::Queryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.query.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n4noie.linmimeng.noiedigitalsystem.api.proto.nds.queryB\nQueryProtoP\001Z)github.com/misty4119/nds-api/Go/nds/query\242\002\003NQX\252\002\tNds.Query\312\002\tNds\\Query\342\002\025Nds\\Query\\GPBMetadata\352\002\nNds::Query'
  _globals['_QUERYBALANCEREQUEST']._serialized_start=230
  _globals['_QUERYBALANCEREQUEST']._serialized_end=434
  _globals['_QUERYBALANCERESPONSE']._serialized_start=437
  _globals['_QUERYBALANCERESPONSE']._serialized_end=570
  _globals['_QUERYHISTORYREQUEST']._serialized_start=573
  _globals['_QUERYHISTORYREQUEST']._serialized_end=990
  _globals['_QUERYHISTORYRESPONSE']._serialized_start=993
  _globals['_QUERYHISTORYRESPONSE']._serialized_end=1140
  _globals['_QUERYPROJECTIONREQUEST']._serialized_start=1143
  _globals['_QUERYPROJECTIONREQUEST']._serialized_end=1302
  _globals['_QUERYPROJECTIONRESPONSE']._serialized_start=1305
  _globals['_QUERYPROJECTIONRESPONSE']._serialized_end=1460
  _globals['_REPLAYREQUEST']._serialized_start=1463
  _globals['_REPLAYREQUEST']._serialized_end=1674
  _globals['_REPLAYRESPONSE']._serialized_start=1677
  _globals['_REPLAYRESPONSE']._serialized_end=1823
  _globals['_REGISTERPROJECTIONREQUEST']._serialized_start=1826
  _globals['_REGISTERPROJECTIONREQUEST']._serialized_end=2012
  _globals['_REGISTERPROJECTIONRESPONSE']._serialized_start=2014
  _globals['_REGISTERPROJECTIONRESPONSE']._serialized_end=2089
  _globals['_UNREGISTERPROJECTIONREQUEST']._serialized_start=2092
  _globals['_UNREGISTERPROJECTIONREQUEST']._serialized_end=2256
  _globals['_UNREGISTERPROJECTIONRESPONSE']._serialized_start=2258
  _globals['_UNREGISTERPROJECTIONRESPONSE']._serialized_end=2335
  _globals['_NDSQUERYSERVICE']._serialized_start=2338
  _globals['_NDSQUERYSERVICE']._serialized_end=2874
# @@protoc_insertion_point(module_scope)
