# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/identity/identity.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/identity/identity.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bnds/identity/identity.proto\x12\x0cnds.identity\"\xff\x01\n\x0bNdsIdentity\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12.\n\x04type\x18\x02 \x01(\x0e\x32\x1a.nds.identity.IdentityTypeR\x04type\x12\x43\n\x08metadata\x18\x03 \x03(\x0b\x32\'.nds.identity.NdsIdentity.MetadataEntryR\x08metadata\x12.\n\x13\x61ttached_policy_ids\x18\n \x03(\tR\x11\x61ttachedPolicyIds\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\x93\x01\n\x0cIdentityType\x12\x1d\n\x19IDENTITY_TYPE_UNSPECIFIED\x10\x00\x12\x18\n\x14IDENTITY_TYPE_PLAYER\x10\x01\x12\x18\n\x14IDENTITY_TYPE_SYSTEM\x10\x02\x12\x14\n\x10IDENTITY_TYPE_AI\x10\x03\x12\x1a\n\x16IDENTITY_TYPE_EXTERNAL\x10\x04\x42\xc7\x01\n7noie.linmimeng.noiedigitalsystem.api.proto.nds.identityB\rIdentityProtoP\x01Z,github.com/misty4119/nds-api/Go/nds/identity\xa2\x02\x03NIX\xaa\x02\x0cNds.Identity\xca\x02\x0cNds\\Identity\xe2\x02\x18Nds\\Identity\\GPBMetadata\xea\x02\rNds::Identityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.identity.identity_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n7noie.linmimeng.noiedigitalsystem.api.proto.nds.identityB\rIdentityProtoP\001Z,github.com/misty4119/nds-api/Go/nds/identity\242\002\003NIX\252\002\014Nds.Identity\312\002\014Nds\\Identity\342\002\030Nds\\Identity\\GPBMetadata\352\002\rNds::Identity'
  _globals['_NDSIDENTITY_METADATAENTRY']._loaded_options = None
  _globals['_NDSIDENTITY_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_IDENTITYTYPE']._serialized_start=304
  _globals['_IDENTITYTYPE']._serialized_end=451
  _globals['_NDSIDENTITY']._serialized_start=46
  _globals['_NDSIDENTITY']._serialized_end=301
  _globals['_NDSIDENTITY_METADATAENTRY']._serialized_start=242
  _globals['_NDSIDENTITY_METADATAENTRY']._serialized_end=301
# @@protoc_insertion_point(module_scope)
