# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/projection/projection.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/projection/projection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fnds/projection/projection.proto\x12\x0ends.projection\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\"<\n\x0cProjectionId\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x18\n\x07version\x18\x02 \x01(\x05R\x07version\"\x8a\x03\n\rNdsProjection\x12,\n\x02id\x18\x01 \x01(\x0b\x32\x1c.nds.projection.ProjectionIdR\x02id\x12\x38\n\x06status\x18\x02 \x01(\x0e\x32 .nds.projection.ProjectionStatusR\x06status\x12\"\n\rlast_event_id\x18\x03 \x01(\tR\x0blastEventId\x12=\n\x0clast_updated\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0blastUpdated\x12(\n\x04\x64\x61ta\x18\x05 \x01(\x0b\x32\x14.google.protobuf.AnyR\x04\x64\x61ta\x12G\n\x08metadata\x18\x06 \x03(\x0b\x32+.nds.projection.NdsProjection.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xa2\x01\n\x11\x42\x61lanceProjection\x12\x18\n\x07\x62\x61lance\x18\x01 \x01(\tR\x07\x62\x61lance\x12\x19\n\x08\x61sset_id\x18\x02 \x01(\tR\x07\x61ssetId\x12\x19\n\x08owner_id\x18\x03 \x01(\tR\x07ownerId\x12=\n\x0clast_updated\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0blastUpdated\"\xe6\x01\n\x10LeaderboardEntry\x12\x12\n\x04rank\x18\x01 \x01(\x05R\x04rank\x12\x1f\n\x0bidentity_id\x18\x02 \x01(\tR\nidentityId\x12\x14\n\x05value\x18\x03 \x01(\tR\x05value\x12J\n\x08metadata\x18\x04 \x03(\x0b\x32..nds.projection.LeaderboardEntry.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xc1\x01\n\x15LeaderboardProjection\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x19\n\x08\x61sset_id\x18\x02 \x01(\tR\x07\x61ssetId\x12:\n\x07\x65ntries\x18\x03 \x03(\x0b\x32 .nds.projection.LeaderboardEntryR\x07\x65ntries\x12=\n\x0clast_updated\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0blastUpdated*\xb2\x01\n\x10ProjectionStatus\x12!\n\x1dPROJECTION_STATUS_UNSPECIFIED\x10\x00\x12\x1c\n\x18PROJECTION_STATUS_ACTIVE\x10\x01\x12 \n\x1cPROJECTION_STATUS_REBUILDING\x10\x02\x12\x1e\n\x1aPROJECTION_STATUS_DISABLED\x10\x03\x12\x1b\n\x17PROJECTION_STATUS_ERROR\x10\x04\x42\xd5\x01\n9noie.linmimeng.noiedigitalsystem.api.proto.nds.projectionB\x0fProjectionProtoP\x01Z.github.com/misty4119/nds-api/Go/nds/projection\xa2\x02\x03NPX\xaa\x02\x0eNds.Projection\xca\x02\x0eNds\\Projection\xe2\x02\x1aNds\\Projection\\GPBMetadata\xea\x02\x0fNds::Projectionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.projection.projection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n9noie.linmimeng.noiedigitalsystem.api.proto.nds.projectionB\017ProjectionProtoP\001Z.github.com/misty4119/nds-api/Go/nds/projection\242\002\003NPX\252\002\016Nds.Projection\312\002\016Nds\\Projection\342\002\032Nds\\Projection\\GPBMetadata\352\002\017Nds::Projection'
  _globals['_NDSPROJECTION_METADATAENTRY']._loaded_options = None
  _globals['_NDSPROJECTION_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_LEADERBOARDENTRY_METADATAENTRY']._loaded_options = None
  _globals['_LEADERBOARDENTRY_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_PROJECTIONSTATUS']._serialized_start=1165
  _globals['_PROJECTIONSTATUS']._serialized_end=1343
  _globals['_PROJECTIONID']._serialized_start=111
  _globals['_PROJECTIONID']._serialized_end=171
  _globals['_NDSPROJECTION']._serialized_start=174
  _globals['_NDSPROJECTION']._serialized_end=568
  _globals['_NDSPROJECTION_METADATAENTRY']._serialized_start=509
  _globals['_NDSPROJECTION_METADATAENTRY']._serialized_end=568
  _globals['_BALANCEPROJECTION']._serialized_start=571
  _globals['_BALANCEPROJECTION']._serialized_end=733
  _globals['_LEADERBOARDENTRY']._serialized_start=736
  _globals['_LEADERBOARDENTRY']._serialized_end=966
  _globals['_LEADERBOARDENTRY_METADATAENTRY']._serialized_start=509
  _globals['_LEADERBOARDENTRY_METADATAENTRY']._serialized_end=568
  _globals['_LEADERBOARDPROJECTION']._serialized_start=969
  _globals['_LEADERBOARDPROJECTION']._serialized_end=1162
# @@protoc_insertion_point(module_scope)
