# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/transaction/transaction.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/transaction/transaction.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nds.common import common_pb2 as nds_dot_common_dot_common__pb2
from nds.identity import identity_pb2 as nds_dot_identity_dot_identity__pb2
from nds.asset import asset_pb2 as nds_dot_asset_dot_asset__pb2
from nds.event import event_pb2 as nds_dot_event_dot_event__pb2
from nds.context import context_pb2 as nds_dot_context_dot_context__pb2
from nds.audit import rationale_pb2 as nds_dot_audit_dot_rationale__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!nds/transaction/transaction.proto\x12\x0fnds.transaction\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17nds/common/common.proto\x1a\x1bnds/identity/identity.proto\x1a\x15nds/asset/asset.proto\x1a\x15nds/event/event.proto\x1a\x19nds/context/context.proto\x1a\x19nds/audit/rationale.proto\"\xbe\x08\n\x0eNdsTransaction\x12\"\n\x02id\x18\x01 \x01(\x0b\x32\x12.nds.event.EventIdR\x02id\x12;\n\x0boccurred_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\noccurredAt\x12/\n\x05\x61\x63tor\x18\x03 \x01(\x0b\x32\x19.nds.identity.NdsIdentityR\x05\x61\x63tor\x12/\n\x07payload\x18\x04 \x01(\x0b\x32\x15.nds.event.NdsPayloadR\x07payload\x12%\n\x0eschema_version\x18\x05 \x01(\x05R\rschemaVersion\x12I\n\x08metadata\x18\x06 \x03(\x0b\x32-.nds.transaction.NdsTransaction.MetadataEntryR\x08metadata\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32\x17.nds.context.NdsContextH\x00R\x07\x63ontext\x88\x01\x01\x12(\n\x05\x61sset\x18\n \x01(\x0b\x32\x12.nds.asset.AssetIdR\x05\x61sset\x12)\n\x05\x64\x65lta\x18\x0b \x01(\x0b\x32\x13.nds.common.DecimalR\x05\x64\x65lta\x12\x42\n\x0b\x63onsistency\x18\x0c \x01(\x0e\x32 .nds.transaction.ConsistencyModeR\x0b\x63onsistency\x12\x36\n\x06source\x18\r \x01(\x0b\x32\x19.nds.identity.NdsIdentityH\x01R\x06source\x88\x01\x01\x12\x36\n\x06target\x18\x0e \x01(\x0b\x32\x19.nds.identity.NdsIdentityH\x02R\x06target\x88\x01\x01\x12\x1b\n\x06reason\x18\x0f \x01(\tH\x03R\x06reason\x88\x01\x01\x12:\n\x06status\x18\x10 \x01(\x0e\x32\".nds.transaction.TransactionStatusR\x06status\x12\x37\n\x15\x65nforcement_policy_id\x18\x11 \x01(\tH\x04R\x13\x65nforcementPolicyId\x88\x01\x01\x12:\n\trationale\x18\x12 \x01(\x0b\x32\x17.nds.audit.NdsRationaleH\x05R\trationale\x88\x01\x01\x12\x44\n\rrationale_ref\x18\x13 \x01(\x0b\x32\x1a.nds.audit.NdsRationaleRefH\x06R\x0crationaleRef\x88\x01\x01\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\n\n\x08_contextB\t\n\x07_sourceB\t\n\x07_targetB\t\n\x07_reasonB\x18\n\x16_enforcement_policy_idB\x0c\n\n_rationaleB\x10\n\x0e_rationale_ref\"\xe8\x04\n\x18\x43reateTransactionRequest\x12(\n\x05\x61sset\x18\x01 \x01(\x0b\x32\x12.nds.asset.AssetIdR\x05\x61sset\x12)\n\x05\x64\x65lta\x18\x02 \x01(\x0b\x32\x13.nds.common.DecimalR\x05\x64\x65lta\x12/\n\x05\x61\x63tor\x18\x03 \x01(\x0b\x32\x19.nds.identity.NdsIdentityR\x05\x61\x63tor\x12\x42\n\x0b\x63onsistency\x18\x04 \x01(\x0e\x32 .nds.transaction.ConsistencyModeR\x0b\x63onsistency\x12\x36\n\x06source\x18\x05 \x01(\x0b\x32\x19.nds.identity.NdsIdentityH\x00R\x06source\x88\x01\x01\x12\x36\n\x06target\x18\x06 \x01(\x0b\x32\x19.nds.identity.NdsIdentityH\x01R\x06target\x88\x01\x01\x12\x1b\n\x06reason\x18\x07 \x01(\tH\x02R\x06reason\x88\x01\x01\x12\x36\n\x07\x63ontext\x18\x08 \x01(\x0b\x32\x17.nds.context.NdsContextH\x03R\x07\x63ontext\x88\x01\x01\x12S\n\x08metadata\x18\t \x03(\x0b\x32\x37.nds.transaction.CreateTransactionRequest.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\t\n\x07_sourceB\t\n\x07_targetB\t\n\x07_reasonB\n\n\x08_context\"\xa2\x01\n\x19\x43reateTransactionResponse\x12-\n\x06result\x18\x01 \x01(\x0b\x32\x15.nds.common.NdsResultR\x06result\x12\x46\n\x0btransaction\x18\x02 \x01(\x0b\x32\x1f.nds.transaction.NdsTransactionH\x00R\x0btransaction\x88\x01\x01\x42\x0e\n\x0c_transaction\"K\n\x1aPreviewTransactionResponse\x12-\n\x06result\x18\x01 \x01(\x0b\x32\x15.nds.common.NdsResultR\x06result\"\xac\x02\n\x1e\x42\x61tchCreateTransactionsRequest\x12\x45\n\x08requests\x18\x01 \x03(\x0b\x32).nds.transaction.CreateTransactionRequestR\x08requests\x12\x1e\n\x08\x62\x61tch_id\x18\x02 \x01(\tH\x00R\x07\x62\x61tchId\x88\x01\x01\x12Y\n\x08metadata\x18\x03 \x03(\x0b\x32=.nds.transaction.BatchCreateTransactionsRequest.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x0b\n\t_batch_id\"\x9a\x01\n\x1f\x42\x61tchCreateTransactionsResponse\x12-\n\x06result\x18\x01 \x01(\x0b\x32\x15.nds.common.NdsResultR\x06result\x12H\n\tresponses\x18\x02 \x03(\x0b\x32*.nds.transaction.CreateTransactionResponseR\tresponses\"\xae\x04\n\x19StreamTransactionsRequest\x12-\n\x05\x61sset\x18\x01 \x01(\x0b\x32\x12.nds.asset.AssetIdH\x00R\x05\x61sset\x88\x01\x01\x12\x34\n\x05\x61\x63tor\x18\x02 \x01(\x0b\x32\x19.nds.identity.NdsIdentityH\x01R\x05\x61\x63tor\x88\x01\x01\x12\x36\n\x06source\x18\x03 \x01(\x0b\x32\x19.nds.identity.NdsIdentityH\x02R\x06source\x88\x01\x01\x12\x36\n\x06target\x18\x04 \x01(\x0b\x32\x19.nds.identity.NdsIdentityH\x03R\x06target\x88\x01\x01\x12\x35\n\x05since\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x04R\x05since\x88\x01\x01\x12>\n\x08statuses\x18\x06 \x03(\x0e\x32\".nds.transaction.TransactionStatusR\x08statuses\x12T\n\x08metadata\x18\x07 \x03(\x0b\x32\x38.nds.transaction.StreamTransactionsRequest.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x08\n\x06_assetB\x08\n\x06_actorB\t\n\x07_sourceB\t\n\x07_targetB\x08\n\x06_since*\x90\x01\n\x0f\x43onsistencyMode\x12 \n\x1c\x43ONSISTENCY_MODE_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x43ONSISTENCY_MODE_STRONG\x10\x01\x12\x1d\n\x19\x43ONSISTENCY_MODE_EVENTUAL\x10\x02\x12\x1f\n\x1b\x43ONSISTENCY_MODE_OPTIMISTIC\x10\x03*\xbc\x01\n\x11TransactionStatus\x12\"\n\x1eTRANSACTION_STATUS_UNSPECIFIED\x10\x00\x12\x1e\n\x1aTRANSACTION_STATUS_PENDING\x10\x01\x12 \n\x1cTRANSACTION_STATUS_COMMITTED\x10\x02\x12\"\n\x1eTRANSACTION_STATUS_ROLLED_BACK\x10\x03\x12\x1d\n\x19TRANSACTION_STATUS_FAILED\x10\x04\x42\xdc\x01\n:noie.linmimeng.noiedigitalsystem.api.proto.nds.transactionB\x10TransactionProtoP\x01Z/github.com/misty4119/nds-api/Go/nds/transaction\xa2\x02\x03NTX\xaa\x02\x0fNds.Transaction\xca\x02\x0fNds\\Transaction\xe2\x02\x1bNds\\Transaction\\GPBMetadata\xea\x02\x10Nds::Transactionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.transaction.transaction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n:noie.linmimeng.noiedigitalsystem.api.proto.nds.transactionB\020TransactionProtoP\001Z/github.com/misty4119/nds-api/Go/nds/transaction\242\002\003NTX\252\002\017Nds.Transaction\312\002\017Nds\\Transaction\342\002\033Nds\\Transaction\\GPBMetadata\352\002\020Nds::Transaction'
  _globals['_NDSTRANSACTION_METADATAENTRY']._loaded_options = None
  _globals['_NDSTRANSACTION_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CREATETRANSACTIONREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_CREATETRANSACTIONREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_BATCHCREATETRANSACTIONSREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_BATCHCREATETRANSACTIONSREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_STREAMTRANSACTIONSREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_STREAMTRANSACTIONSREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CONSISTENCYMODE']._serialized_start=3213
  _globals['_CONSISTENCYMODE']._serialized_end=3357
  _globals['_TRANSACTIONSTATUS']._serialized_start=3360
  _globals['_TRANSACTIONSTATUS']._serialized_end=3548
  _globals['_NDSTRANSACTION']._serialized_start=242
  _globals['_NDSTRANSACTION']._serialized_end=1328
  _globals['_NDSTRANSACTION_METADATAENTRY']._serialized_start=1166
  _globals['_NDSTRANSACTION_METADATAENTRY']._serialized_end=1225
  _globals['_CREATETRANSACTIONREQUEST']._serialized_start=1331
  _globals['_CREATETRANSACTIONREQUEST']._serialized_end=1947
  _globals['_CREATETRANSACTIONREQUEST_METADATAENTRY']._serialized_start=1166
  _globals['_CREATETRANSACTIONREQUEST_METADATAENTRY']._serialized_end=1225
  _globals['_CREATETRANSACTIONRESPONSE']._serialized_start=1950
  _globals['_CREATETRANSACTIONRESPONSE']._serialized_end=2112
  _globals['_PREVIEWTRANSACTIONRESPONSE']._serialized_start=2114
  _globals['_PREVIEWTRANSACTIONRESPONSE']._serialized_end=2189
  _globals['_BATCHCREATETRANSACTIONSREQUEST']._serialized_start=2192
  _globals['_BATCHCREATETRANSACTIONSREQUEST']._serialized_end=2492
  _globals['_BATCHCREATETRANSACTIONSREQUEST_METADATAENTRY']._serialized_start=1166
  _globals['_BATCHCREATETRANSACTIONSREQUEST_METADATAENTRY']._serialized_end=1225
  _globals['_BATCHCREATETRANSACTIONSRESPONSE']._serialized_start=2495
  _globals['_BATCHCREATETRANSACTIONSRESPONSE']._serialized_end=2649
  _globals['_STREAMTRANSACTIONSREQUEST']._serialized_start=2652
  _globals['_STREAMTRANSACTIONSREQUEST']._serialized_end=3210
  _globals['_STREAMTRANSACTIONSREQUEST_METADATAENTRY']._serialized_start=1166
  _globals['_STREAMTRANSACTIONSREQUEST_METADATAENTRY']._serialized_end=1225
# @@protoc_insertion_point(module_scope)
