# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/audit/rationale.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/audit/rationale.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nds.common import common_pb2 as nds_dot_common_dot_common__pb2
from nds.event import event_pb2 as nds_dot_event_dot_event__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19nds/audit/rationale.proto\x12\tnds.audit\x1a\x17nds/common/common.proto\x1a\x15nds/event/event.proto\"\xdd\x03\n\x0cNdsRationale\x12\x16\n\x06source\x18\x01 \x01(\tR\x06source\x12\x38\n\nconfidence\x18\x02 \x01(\x0b\x32\x13.nds.common.DecimalH\x00R\nconfidence\x88\x01\x01\x12!\n\x0cthought_path\x18\x03 \x03(\tR\x0bthoughtPath\x12@\n\x12\x65vidence_event_ids\x18\x04 \x03(\x0b\x32\x12.nds.event.EventIdR\x10\x65videnceEventIds\x12?\n\revidence_refs\x18\x08 \x03(\x0b\x32\x1a.nds.audit.NdsRationaleRefR\x0c\x65videnceRefs\x12\x37\n\nrisk_score\x18\x05 \x01(\x0b\x32\x13.nds.common.DecimalH\x01R\triskScore\x88\x01\x01\x12\x41\n\x08metadata\x18\x06 \x03(\x0b\x32%.nds.audit.NdsRationale.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\r\n\x0b_confidenceB\r\n\x0b_risk_score\"u\n\x0fNdsRationaleRef\x12\x10\n\x03uri\x18\x01 \x01(\tR\x03uri\x12\x17\n\x04hash\x18\x02 \x01(\tH\x00R\x04hash\x88\x01\x01\x12 \n\tmime_type\x18\x03 \x01(\tH\x01R\x08mimeType\x88\x01\x01\x42\x07\n\x05_hashB\x0c\n\n_mime_typeB\xb6\x01\n4noie.linmimeng.noiedigitalsystem.api.proto.nds.auditB\x0eRationaleProtoP\x01Z)github.com/misty4119/nds-api/Go/nds/audit\xa2\x02\x03NAX\xaa\x02\tNds.Audit\xca\x02\tNds\\Audit\xe2\x02\x15Nds\\Audit\\GPBMetadata\xea\x02\nNds::Auditb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.audit.rationale_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n4noie.linmimeng.noiedigitalsystem.api.proto.nds.auditB\016RationaleProtoP\001Z)github.com/misty4119/nds-api/Go/nds/audit\242\002\003NAX\252\002\tNds.Audit\312\002\tNds\\Audit\342\002\025Nds\\Audit\\GPBMetadata\352\002\nNds::Audit'
  _globals['_NDSRATIONALE_METADATAENTRY']._loaded_options = None
  _globals['_NDSRATIONALE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_NDSRATIONALE']._serialized_start=89
  _globals['_NDSRATIONALE']._serialized_end=566
  _globals['_NDSRATIONALE_METADATAENTRY']._serialized_start=477
  _globals['_NDSRATIONALE_METADATAENTRY']._serialized_end=536
  _globals['_NDSRATIONALEREF']._serialized_start=568
  _globals['_NDSRATIONALEREF']._serialized_end=685
# @@protoc_insertion_point(module_scope)
