# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/event/v1/event_v1.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/event/v1/event_v1.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nds.common.v1 import common_v1_pb2 as nds_dot_common_dot_v1_dot_common__v1__pb2
from nds.identity.v1 import identity_v1_pb2 as nds_dot_identity_dot_v1_dot_identity__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bnds/event/v1/event_v1.proto\x12\x0cnds.event.v1\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dnds/common/v1/common_v1.proto\x1a!nds/identity/v1/identity_v1.proto\"\x1e\n\x06\x43ursor\x12\x14\n\x05value\x18\x01 \x01(\x0cR\x05value\"\xb3\x04\n\rEventEnvelope\x12\x19\n\x08\x65vent_id\x18\x01 \x01(\x0cR\x07\x65ventId\x12,\n\x06\x63ursor\x18\x02 \x01(\x0b\x32\x14.nds.event.v1.CursorR\x06\x63ursor\x12;\n\x0boccurred_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\noccurredAt\x12\x30\n\x05\x61\x63tor\x18\n \x01(\x0b\x32\x1a.nds.identity.v1.PersonaIdR\x05\x61\x63tor\x12\x35\n\x05owner\x18\x0b \x01(\x0b\x32\x1a.nds.identity.v1.PersonaIdH\x00R\x05owner\x88\x01\x01\x12+\n\x04type\x18\x14 \x01(\x0e\x32\x17.nds.event.v1.EventTypeR\x04type\x12%\n\x0eschema_version\x18\x15 \x01(\x05R\rschemaVersion\x12.\n\x07payload\x18\x1e \x01(\x0b\x32\x14.google.protobuf.AnyR\x07payload\x12\x34\n\nextensions\x18\x1f \x03(\x0b\x32\x14.google.protobuf.AnyR\nextensions\x12\x34\n\x03\x63tx\x18( \x01(\x0b\x32\x1d.nds.common.v1.RequestContextH\x01R\x03\x63tx\x88\x01\x01\x12\"\n\nrequest_id\x18) \x01(\tH\x02R\trequestId\x88\x01\x01\x42\x08\n\x06_ownerB\x06\n\x04_ctxB\r\n\x0b_request_id*\xba\x01\n\tEventType\x12\x1a\n\x16\x45VENT_TYPE_UNSPECIFIED\x10\x00\x12\"\n\x1e\x45VENT_TYPE_LEDGER_TX_COMMITTED\x10\x01\x12%\n!EVENT_TYPE_LEDGER_BALANCE_CHANGED\x10\x02\x12\x1d\n\x19\x45VENT_TYPE_IDENTITY_BOUND\x10\n\x12\'\n#EVENT_TYPE_MEMORY_ARTIFACT_ANCHORED\x10\x14\x42\xcf\x01\n7noie.linmimeng.noiedigitalsystem.api.proto.nds.event.v1B\x0c\x45ventV1ProtoP\x01Z4github.com/misty4119/nds-api/Go/nds/event/v1;eventv1\xa2\x02\x03NEX\xaa\x02\x0cNds.Event.V1\xca\x02\x0cNds\\Event\\V1\xe2\x02\x18Nds\\Event\\V1\\GPBMetadata\xea\x02\x0eNds::Event::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.event.v1.event_v1_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n7noie.linmimeng.noiedigitalsystem.api.proto.nds.event.v1B\014EventV1ProtoP\001Z4github.com/misty4119/nds-api/Go/nds/event/v1;eventv1\242\002\003NEX\252\002\014Nds.Event.V1\312\002\014Nds\\Event\\V1\342\002\030Nds\\Event\\V1\\GPBMetadata\352\002\016Nds::Event::V1'
  _globals['_EVENTTYPE']._serialized_start=770
  _globals['_EVENTTYPE']._serialized_end=956
  _globals['_CURSOR']._serialized_start=171
  _globals['_CURSOR']._serialized_end=201
  _globals['_EVENTENVELOPE']._serialized_start=204
  _globals['_EVENTENVELOPE']._serialized_end=767
# @@protoc_insertion_point(module_scope)
