# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/metadata/v1/metadata.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/metadata/v1/metadata.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ends/metadata/v1/metadata.proto\x12\x0fnds.metadata.v1\x1a\x19google/protobuf/any.proto\"\xae\x01\n\x0f\x44isplayMetadata\x12&\n\x0c\x64isplay_name\x18\x01 \x01(\tH\x00R\x0b\x64isplayName\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12\x1e\n\x08icon_uri\x18\x03 \x01(\tH\x02R\x07iconUri\x88\x01\x01\x42\x0f\n\r_display_nameB\x0e\n\x0c_descriptionB\x0b\n\t_icon_uri\"\xac\x01\n\x0eSourceMetadata\x12(\n\rsource_system\x18\x01 \x01(\tH\x00R\x0csourceSystem\x88\x01\x01\x12$\n\x0b\x63\x61mpaign_id\x18\x02 \x01(\tH\x01R\ncampaignId\x88\x01\x01\x12\x1c\n\x07task_id\x18\x03 \x01(\tH\x02R\x06taskId\x88\x01\x01\x42\x10\n\x0e_source_systemB\x0e\n\x0c_campaign_idB\n\n\x08_task_id\"\xf9\x02\n\x0eMetadataBundle\x12?\n\x07\x64isplay\x18\x01 \x01(\x0b\x32 .nds.metadata.v1.DisplayMetadataH\x00R\x07\x64isplay\x88\x01\x01\x12<\n\x06source\x18\x02 \x01(\x0b\x32\x1f.nds.metadata.v1.SourceMetadataH\x01R\x06source\x88\x01\x01\x12\x34\n\nextensions\x18\n \x03(\x0b\x32\x14.google.protobuf.AnyR\nextensions\x12Y\n\x0elegacy_entries\x18\x63 \x03(\x0b\x32\x32.nds.metadata.v1.MetadataBundle.LegacyEntriesEntryR\rlegacyEntries\x1a@\n\x12LegacyEntriesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\n\n\x08_displayB\t\n\x07_sourceB\xe5\x01\n:noie.linmimeng.noiedigitalsystem.api.proto.nds.metadata.v1B\rMetadataProtoP\x01Z:github.com/misty4119/nds-api/Go/nds/metadata/v1;metadatav1\xa2\x02\x03NMX\xaa\x02\x0fNds.Metadata.V1\xca\x02\x0fNds\\Metadata\\V1\xe2\x02\x1bNds\\Metadata\\V1\\GPBMetadata\xea\x02\x11Nds::Metadata::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.metadata.v1.metadata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n:noie.linmimeng.noiedigitalsystem.api.proto.nds.metadata.v1B\rMetadataProtoP\001Z:github.com/misty4119/nds-api/Go/nds/metadata/v1;metadatav1\242\002\003NMX\252\002\017Nds.Metadata.V1\312\002\017Nds\\Metadata\\V1\342\002\033Nds\\Metadata\\V1\\GPBMetadata\352\002\021Nds::Metadata::V1'
  _globals['_METADATABUNDLE_LEGACYENTRIESENTRY']._loaded_options = None
  _globals['_METADATABUNDLE_LEGACYENTRIESENTRY']._serialized_options = b'8\001'
  _globals['_DISPLAYMETADATA']._serialized_start=79
  _globals['_DISPLAYMETADATA']._serialized_end=253
  _globals['_SOURCEMETADATA']._serialized_start=256
  _globals['_SOURCEMETADATA']._serialized_end=428
  _globals['_METADATABUNDLE']._serialized_start=431
  _globals['_METADATABUNDLE']._serialized_end=808
  _globals['_METADATABUNDLE_LEGACYENTRIESENTRY']._serialized_start=721
  _globals['_METADATABUNDLE_LEGACYENTRIESENTRY']._serialized_end=785
# @@protoc_insertion_point(module_scope)
