# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/policy/policy.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/policy/policy.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17nds/policy/policy.proto\x12\nnds.policy\"\xe2\x02\n\tNdsPolicy\x12\x1b\n\tpolicy_id\x18\x01 \x01(\tR\x08policyId\x12\x1f\n\x0bpolicy_type\x18\x02 \x01(\tR\npolicyType\x12\x39\n\x06params\x18\x03 \x03(\x0b\x32!.nds.policy.NdsPolicy.ParamsEntryR\x06params\x12#\n\rcustom_config\x18\x04 \x01(\x0cR\x0c\x63ustomConfig\x12?\n\x08metadata\x18\x05 \x03(\x0b\x32#.nds.policy.NdsPolicy.MetadataEntryR\x08metadata\x1a\x39\n\x0bParamsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\xb9\x01\n5noie.linmimeng.noiedigitalsystem.api.proto.nds.policyB\x0bPolicyProtoP\x01Z*github.com/misty4119/nds-api/Go/nds/policy\xa2\x02\x03NPX\xaa\x02\nNds.Policy\xca\x02\nNds\\Policy\xe2\x02\x16Nds\\Policy\\GPBMetadata\xea\x02\x0bNds::Policyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.policy.policy_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n5noie.linmimeng.noiedigitalsystem.api.proto.nds.policyB\013PolicyProtoP\001Z*github.com/misty4119/nds-api/Go/nds/policy\242\002\003NPX\252\002\nNds.Policy\312\002\nNds\\Policy\342\002\026Nds\\Policy\\GPBMetadata\352\002\013Nds::Policy'
  _globals['_NDSPOLICY_PARAMSENTRY']._loaded_options = None
  _globals['_NDSPOLICY_PARAMSENTRY']._serialized_options = b'8\001'
  _globals['_NDSPOLICY_METADATAENTRY']._loaded_options = None
  _globals['_NDSPOLICY_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_NDSPOLICY']._serialized_start=40
  _globals['_NDSPOLICY']._serialized_end=394
  _globals['_NDSPOLICY_PARAMSENTRY']._serialized_start=276
  _globals['_NDSPOLICY_PARAMSENTRY']._serialized_end=333
  _globals['_NDSPOLICY_METADATAENTRY']._serialized_start=335
  _globals['_NDSPOLICY_METADATAENTRY']._serialized_end=394
# @@protoc_insertion_point(module_scope)
