# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/identity/v1/identity_v1.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/identity/v1/identity_v1.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!nds/identity/v1/identity_v1.proto\x12\x0fnds.identity.v1\"!\n\tPersonaId\x12\x14\n\x05value\x18\x01 \x01(\x0cR\x05value\"\xc4\x01\n\x16\x45xternalAccountBinding\x12=\n\x08provider\x18\x01 \x01(\x0e\x32!.nds.identity.v1.ExternalProviderR\x08provider\x12\x1f\n\x0b\x65xternal_id\x18\x02 \x01(\tR\nexternalId\x12%\n\x0everified_level\x18\x03 \x01(\x05R\rverifiedLevel\x12#\n\rbinding_proof\x18\x04 \x01(\x0cR\x0c\x62indingProof\"z\n\x07Persona\x12*\n\x02id\x18\x01 \x01(\x0b\x32\x1a.nds.identity.v1.PersonaIdR\x02id\x12\x43\n\x08\x62indings\x18\x02 \x03(\x0b\x32\'.nds.identity.v1.ExternalAccountBindingR\x08\x62indings*\xaf\x01\n\x10\x45xternalProvider\x12!\n\x1d\x45XTERNAL_PROVIDER_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x45XTERNAL_PROVIDER_MINECRAFT\x10\x01\x12\x1d\n\x19\x45XTERNAL_PROVIDER_DISCORD\x10\x02\x12\x1a\n\x16\x45XTERNAL_PROVIDER_OIDC\x10\x03\x12\x1c\n\x18\x45XTERNAL_PROVIDER_DEVICE\x10\x04\x42\xe7\x01\n:noie.linmimeng.noiedigitalsystem.api.proto.nds.identity.v1B\x0fIdentityV1ProtoP\x01Z:github.com/misty4119/nds-api/Go/nds/identity/v1;identityv1\xa2\x02\x03NIX\xaa\x02\x0fNds.Identity.V1\xca\x02\x0fNds\\Identity\\V1\xe2\x02\x1bNds\\Identity\\V1\\GPBMetadata\xea\x02\x11Nds::Identity::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.identity.v1.identity_v1_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n:noie.linmimeng.noiedigitalsystem.api.proto.nds.identity.v1B\017IdentityV1ProtoP\001Z:github.com/misty4119/nds-api/Go/nds/identity/v1;identityv1\242\002\003NIX\252\002\017Nds.Identity.V1\312\002\017Nds\\Identity\\V1\342\002\033Nds\\Identity\\V1\\GPBMetadata\352\002\021Nds::Identity::V1'
  _globals['_EXTERNALPROVIDER']._serialized_start=413
  _globals['_EXTERNALPROVIDER']._serialized_end=588
  _globals['_PERSONAID']._serialized_start=54
  _globals['_PERSONAID']._serialized_end=87
  _globals['_EXTERNALACCOUNTBINDING']._serialized_start=90
  _globals['_EXTERNALACCOUNTBINDING']._serialized_end=286
  _globals['_PERSONA']._serialized_start=288
  _globals['_PERSONA']._serialized_end=410
# @@protoc_insertion_point(module_scope)
