# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/context/context.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/context/context.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19nds/context/context.proto\x12\x0bnds.context\"\xc4\x02\n\nNdsContext\x12\x19\n\x08trace_id\x18\x01 \x01(\tR\x07traceId\x12%\n\x0e\x63orrelation_id\x18\x02 \x01(\tR\rcorrelationId\x12\x1c\n\x07span_id\x18\x03 \x01(\tH\x00R\x06spanId\x88\x01\x01\x12)\n\x0eparent_span_id\x18\x04 \x01(\tH\x01R\x0cparentSpanId\x88\x01\x01\x12\x35\n\x04meta\x18\x05 \x03(\x0b\x32!.nds.context.NdsContext.MetaEntryR\x04meta\x12\x1c\n\ttimestamp\x18\x06 \x01(\x03R\ttimestamp\x1a\x37\n\tMetaEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\n\n\x08_span_idB\x11\n\x0f_parent_span_idB\xc0\x01\n6noie.linmimeng.noiedigitalsystem.api.proto.nds.contextB\x0c\x43ontextProtoP\x01Z+github.com/misty4119/nds-api/Go/nds/context\xa2\x02\x03NCX\xaa\x02\x0bNds.Context\xca\x02\x0bNds\\Context\xe2\x02\x17Nds\\Context\\GPBMetadata\xea\x02\x0cNds::Contextb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.context.context_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n6noie.linmimeng.noiedigitalsystem.api.proto.nds.contextB\014ContextProtoP\001Z+github.com/misty4119/nds-api/Go/nds/context\242\002\003NCX\252\002\013Nds.Context\312\002\013Nds\\Context\342\002\027Nds\\Context\\GPBMetadata\352\002\014Nds::Context'
  _globals['_NDSCONTEXT_METAENTRY']._loaded_options = None
  _globals['_NDSCONTEXT_METAENTRY']._serialized_options = b'8\001'
  _globals['_NDSCONTEXT']._serialized_start=43
  _globals['_NDSCONTEXT']._serialized_end=367
  _globals['_NDSCONTEXT_METAENTRY']._serialized_start=281
  _globals['_NDSCONTEXT_METAENTRY']._serialized_end=336
# @@protoc_insertion_point(module_scope)
