# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/memory/v1/memory.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/memory/v1/memory.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nds.identity.v1 import identity_v1_pb2 as nds_dot_identity_dot_v1_dot_identity__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ands/memory/v1/memory.proto\x12\rnds.memory.v1\x1a!nds/identity/v1/identity_v1.proto\":\n\x04Hash\x12\x1c\n\talgorithm\x18\x01 \x01(\tR\talgorithm\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value\"\xc8\x02\n\x0bMemoryProof\x12#\n\x0bproof_tx_id\x18\x01 \x01(\x0cH\x00R\tproofTxId\x88\x01\x01\x12)\n\x0eproof_event_id\x18\x02 \x01(\x0cH\x01R\x0cproofEventId\x88\x01\x01\x12\x36\n\x0c\x63ontent_hash\x18\n \x01(\x0b\x32\x13.nds.memory.v1.HashR\x0b\x63ontentHash\x12\x35\n\tprev_hash\x18\x0b \x01(\x0b\x32\x13.nds.memory.v1.HashH\x02R\x08prevHash\x88\x01\x01\x12\x39\n\x0bmerkle_root\x18\x0c \x01(\x0b\x32\x13.nds.memory.v1.HashH\x03R\nmerkleRoot\x88\x01\x01\x42\x0e\n\x0c_proof_tx_idB\x11\n\x0f_proof_event_idB\x0c\n\n_prev_hashB\x0e\n\x0c_merkle_root\"\xff\x02\n\x0eMemoryArtifact\x12\x0e\n\x02id\x18\x01 \x01(\x0cR\x02id\x12\x30\n\x05owner\x18\x02 \x01(\x0b\x32\x1a.nds.identity.v1.PersonaIdR\x05owner\x12%\n\x0eschema_version\x18\x03 \x01(\x05R\rschemaVersion\x12!\n\tnarrative\x18\n \x01(\tH\x00R\tnarrative\x88\x01\x01\x12 \n\tembedding\x18\x0b \x03(\x02\x42\x02\x10\x01R\tembedding\x12\x30\n\x05proof\x18\x14 \x01(\x0b\x32\x1a.nds.memory.v1.MemoryProofR\x05proof\x12\x1a\n\x08redacted\x18\x1e \x01(\x08R\x08redacted\x12N\n\x10redaction_reason\x18\x1f \x01(\x0e\x32\x1e.nds.memory.v1.RedactionReasonH\x01R\x0fredactionReason\x88\x01\x01\x42\x0c\n\n_narrativeB\x13\n\x11_redaction_reason*\x92\x01\n\x0fRedactionReason\x12 \n\x1cREDACTION_REASON_UNSPECIFIED\x10\x00\x12$\n REDACTION_REASON_PRIVACY_REQUEST\x10\x01\x12\x1b\n\x17REDACTION_REASON_POLICY\x10\x02\x12\x1a\n\x16REDACTION_REASON_LEGAL\x10\x03\x42\xd5\x01\n8noie.linmimeng.noiedigitalsystem.api.proto.nds.memory.v1B\x0bMemoryProtoP\x01Z6github.com/misty4119/nds-api/Go/nds/memory/v1;memoryv1\xa2\x02\x03NMX\xaa\x02\rNds.Memory.V1\xca\x02\rNds\\Memory\\V1\xe2\x02\x19Nds\\Memory\\V1\\GPBMetadata\xea\x02\x0fNds::Memory::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.memory.v1.memory_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n8noie.linmimeng.noiedigitalsystem.api.proto.nds.memory.v1B\013MemoryProtoP\001Z6github.com/misty4119/nds-api/Go/nds/memory/v1;memoryv1\242\002\003NMX\252\002\rNds.Memory.V1\312\002\rNds\\Memory\\V1\342\002\031Nds\\Memory\\V1\\GPBMetadata\352\002\017Nds::Memory::V1'
  _globals['_MEMORYARTIFACT'].fields_by_name['embedding']._loaded_options = None
  _globals['_MEMORYARTIFACT'].fields_by_name['embedding']._serialized_options = b'\020\001'
  _globals['_REDACTIONREASON']._serialized_start=858
  _globals['_REDACTIONREASON']._serialized_end=1004
  _globals['_HASH']._serialized_start=80
  _globals['_HASH']._serialized_end=138
  _globals['_MEMORYPROOF']._serialized_start=141
  _globals['_MEMORYPROOF']._serialized_end=469
  _globals['_MEMORYARTIFACT']._serialized_start=472
  _globals['_MEMORYARTIFACT']._serialized_end=855
# @@protoc_insertion_point(module_scope)
