# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/common/common.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/common/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17nds/common/common.proto\x12\nnds.common\"5\n\x07\x44\x65\x63imal\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\x12\x14\n\x05scale\x18\x02 \x01(\x05R\x05scale\"`\n\tNdsResult\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12/\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x14.nds.common.NdsErrorH\x00R\x05\x65rror\x88\x01\x01\x42\x08\n\x06_error\"\xb1\x01\n\x08NdsError\x12\x12\n\x04\x63ode\x18\x01 \x01(\tR\x04\x63ode\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12;\n\x07\x64\x65tails\x18\x03 \x03(\x0b\x32!.nds.common.NdsError.DetailsEntryR\x07\x64\x65tails\x1a:\n\x0c\x44\x65tailsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x83\x01\n\x08Metadata\x12;\n\x07\x65ntries\x18\x01 \x03(\x0b\x32!.nds.common.Metadata.EntriesEntryR\x07\x65ntries\x1a:\n\x0c\x45ntriesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\xce\x04\n\tErrorCode\x12\x1a\n\x16\x45RROR_CODE_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x45RROR_CODE_ASSET_NOT_FOUND\x10\x01\x12#\n\x1f\x45RROR_CODE_ASSET_ALREADY_EXISTS\x10\x02\x12#\n\x1f\x45RROR_CODE_INSUFFICIENT_BALANCE\x10\x03\x12#\n\x1f\x45RROR_CODE_ASSET_LIMIT_EXCEEDED\x10\x04\x12!\n\x1d\x45RROR_CODE_IDENTITY_NOT_FOUND\x10\n\x12\x1f\n\x1b\x45RROR_CODE_IDENTITY_INVALID\x10\x0b\x12!\n\x1d\x45RROR_CODE_TRANSACTION_FAILED\x10\x14\x12&\n\"ERROR_CODE_TRANSACTION_ROLLED_BACK\x10\x15\x12$\n ERROR_CODE_CONSISTENCY_VIOLATION\x10\x16\x12%\n!ERROR_CODE_SYSTEM_NOT_INITIALIZED\x10\x1e\x12\x1b\n\x17\x45RROR_CODE_SYSTEM_ERROR\x10\x1f\x12\x16\n\x12\x45RROR_CODE_TIMEOUT\x10 \x12\x1f\n\x1b\x45RROR_CODE_INVALID_ARGUMENT\x10(\x12 \n\x1c\x45RROR_CODE_PERMISSION_DENIED\x10)\x12\x1f\n\x1b\x45RROR_CODE_POLICY_VIOLATION\x10*\x12!\n\x1d\x45RROR_CODE_RATIONALE_REQUIRED\x10+B\xb9\x01\n5noie.linmimeng.noiedigitalsystem.api.proto.nds.commonB\x0b\x43ommonProtoP\x01Z*github.com/misty4119/nds-api/Go/nds/common\xa2\x02\x03NCX\xaa\x02\nNds.Common\xca\x02\nNds\\Common\xe2\x02\x16Nds\\Common\\GPBMetadata\xea\x02\x0bNds::Commonb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.common.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n5noie.linmimeng.noiedigitalsystem.api.proto.nds.commonB\013CommonProtoP\001Z*github.com/misty4119/nds-api/Go/nds/common\242\002\003NCX\252\002\nNds.Common\312\002\nNds\\Common\342\002\026Nds\\Common\\GPBMetadata\352\002\013Nds::Common'
  _globals['_NDSERROR_DETAILSENTRY']._loaded_options = None
  _globals['_NDSERROR_DETAILSENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_ENTRIESENTRY']._loaded_options = None
  _globals['_METADATA_ENTRIESENTRY']._serialized_options = b'8\001'
  _globals['_ERRORCODE']._serialized_start=507
  _globals['_ERRORCODE']._serialized_end=1097
  _globals['_DECIMAL']._serialized_start=39
  _globals['_DECIMAL']._serialized_end=92
  _globals['_NDSRESULT']._serialized_start=94
  _globals['_NDSRESULT']._serialized_end=190
  _globals['_NDSERROR']._serialized_start=193
  _globals['_NDSERROR']._serialized_end=370
  _globals['_NDSERROR_DETAILSENTRY']._serialized_start=312
  _globals['_NDSERROR_DETAILSENTRY']._serialized_end=370
  _globals['_METADATA']._serialized_start=373
  _globals['_METADATA']._serialized_end=504
  _globals['_METADATA_ENTRIESENTRY']._serialized_start=446
  _globals['_METADATA_ENTRIESENTRY']._serialized_end=504
# @@protoc_insertion_point(module_scope)
