# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/event/event.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/event/event.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from nds.identity import identity_pb2 as nds_dot_identity_dot_identity__pb2
from nds.context import context_pb2 as nds_dot_context_dot_context__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15nds/event/event.proto\x12\tnds.event\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1bnds/identity/identity.proto\x1a\x19nds/context/context.proto\"\x1f\n\x07\x45ventId\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\"9\n\nNdsPayload\x12+\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructR\x04\x64\x61ta\"\xde\x03\n\x08NdsEvent\x12\"\n\x02id\x18\x01 \x01(\x0b\x32\x12.nds.event.EventIdR\x02id\x12;\n\x0boccurred_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\noccurredAt\x12/\n\x05\x61\x63tor\x18\x03 \x01(\x0b\x32\x19.nds.identity.NdsIdentityR\x05\x61\x63tor\x12(\n\x04type\x18\x04 \x01(\x0e\x32\x14.nds.event.EventTypeR\x04type\x12/\n\x07payload\x18\x05 \x01(\x0b\x32\x15.nds.event.NdsPayloadR\x07payload\x12%\n\x0eschema_version\x18\x06 \x01(\x05R\rschemaVersion\x12=\n\x08metadata\x18\x07 \x03(\x0b\x32!.nds.event.NdsEvent.MetadataEntryR\x08metadata\x12\x36\n\x07\x63ontext\x18\x08 \x01(\x0b\x32\x17.nds.context.NdsContextH\x00R\x07\x63ontext\x88\x01\x01\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\n\n\x08_context*\x8d\x02\n\tEventType\x12\x1a\n\x16\x45VENT_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x45VENT_TYPE_TRANSACTION\x10\x01\x12\x1c\n\x18\x45VENT_TYPE_ASSET_CREATED\x10\x02\x12\x1c\n\x18\x45VENT_TYPE_ASSET_UPDATED\x10\x03\x12\x1c\n\x18\x45VENT_TYPE_ASSET_DELETED\x10\x04\x12\x1f\n\x1b\x45VENT_TYPE_IDENTITY_CREATED\x10\x05\x12\x1f\n\x1b\x45VENT_TYPE_IDENTITY_UPDATED\x10\x06\x12\x15\n\x11\x45VENT_TYPE_SYSTEM\x10\x07\x12\x15\n\x11\x45VENT_TYPE_CUSTOM\x10\x63\x42\xb2\x01\n4noie.linmimeng.noiedigitalsystem.api.proto.nds.eventB\nEventProtoP\x01Z)github.com/misty4119/nds-api/Go/nds/event\xa2\x02\x03NEX\xaa\x02\tNds.Event\xca\x02\tNds\\Event\xe2\x02\x15Nds\\Event\\GPBMetadata\xea\x02\nNds::Eventb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.event.event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n4noie.linmimeng.noiedigitalsystem.api.proto.nds.eventB\nEventProtoP\001Z)github.com/misty4119/nds-api/Go/nds/event\242\002\003NEX\252\002\tNds.Event\312\002\tNds\\Event\342\002\025Nds\\Event\\GPBMetadata\352\002\nNds::Event'
  _globals['_NDSEVENT_METADATAENTRY']._loaded_options = None
  _globals['_NDSEVENT_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_EVENTTYPE']._serialized_start=729
  _globals['_EVENTTYPE']._serialized_end=998
  _globals['_EVENTID']._serialized_start=155
  _globals['_EVENTID']._serialized_end=186
  _globals['_NDSPAYLOAD']._serialized_start=188
  _globals['_NDSPAYLOAD']._serialized_end=245
  _globals['_NDSEVENT']._serialized_start=248
  _globals['_NDSEVENT']._serialized_end=726
  _globals['_NDSEVENT_METADATAENTRY']._serialized_start=655
  _globals['_NDSEVENT_METADATAENTRY']._serialized_end=714
# @@protoc_insertion_point(module_scope)
